@@ -1,7 +1,10 @@
 /* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /*
-$Id: icqlib.c,v 1.44 2000/07/24 03:10:08 bills Exp $
+$Id: icqlib.c,v 1.1.1.1 2001/05/12 16:50:57 konst Exp $
 $Log: icqlib.c,v $
+Revision 1.1.1.1  2001/05/12 16:50:57  konst
+Imported into the CVS repository
+
 Revision 1.44  2000/07/24 03:10:08  bills
 added support for real nickname during TCP transactions like file and
 chat, instead of using Bill all the time (hmm, where'd I get that from? :)
@@ -230,57 +233,6 @@ DWORD icq_SendContact(ICQLINK *link, DWORD uin, const icqcontactmsg *contact, BY
   return 0;
 }
 
-DWORD icq_SendAuthReq(ICQLINK *link, DWORD uin, const char *nick, const char *first,
-                      const char *last, const char *email, const char *reason,
-                      BYTE thruSrv)
-{
-  if(thruSrv==ICQ_SEND_THRUSERVER)
-    return icq_UDPSendAuthReq(link, uin, nick, first, last, email, reason);
-  else if(thruSrv==ICQ_SEND_DIRECT)
-    return icq_TCPSendAuthReq(link, uin, nick, first, last, email, reason);
-  else if(thruSrv==ICQ_SEND_BESTWAY)
-  {
-    icq_ContactItem *pcontact=icq_ContactFind(link, uin);
-    if(pcontact)
-    {
-      if(pcontact->tcp_flag == 0x04)
-        return icq_TCPSendAuthReq(link, uin, nick, first, last, email, reason);
-      else
-        return icq_UDPSendAuthReq(link, uin, nick, first, last, email, reason);
-    }
-    else
-    {
-      return icq_UDPSendAuthReq(link, uin, nick, first, last, email, reason);
-    }
-  }
-  return 0;
-}
-
-DWORD icq_SendAdded(ICQLINK *link, DWORD uin, const char *nick, const char *first,
-                    const char *last, const char *email, BYTE thruSrv)
-{
-  if(thruSrv==ICQ_SEND_THRUSERVER)
-    return icq_UDPSendAdded(link, uin, nick, first, last, email);
-  else if(thruSrv==ICQ_SEND_DIRECT)
-    return icq_TCPSendAdded(link, uin, nick, first, last, email);
-  else if(thruSrv==ICQ_SEND_BESTWAY)
-  {
-    icq_ContactItem *pcontact=icq_ContactFind(link, uin);
-    if(pcontact)
-    {
-      if(pcontact->tcp_flag == 0x04)
-        return icq_TCPSendAdded(link, uin, nick, first, last, email);
-      else
-        return icq_UDPSendAdded(link, uin, nick, first, last, email);
-    }
-    else
-    {
-      return icq_UDPSendAdded(link, uin, nick, first, last, email);
-    }
-  }
-  return 0;
-}
-
 void icq_Init(ICQLINK *link, DWORD uin, const char *password,
   const char *nick)
 {
