@@ -1,7 +1,10 @@
 /* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /*
-$Id: tcp.c,v 1.36 2000/07/09 22:19:35 bills Exp $
+$Id: tcp.c,v 1.1.1.1 2001/05/12 16:50:57 konst Exp $
 $Log: tcp.c,v $
+Revision 1.1.1.1  2001/05/12 16:50:57  konst
+Imported into the CVS repository
+
 Revision 1.36  2000/07/09 22:19:35  bills
 added new *Close functions, use *Close functions instead of *Delete
 where correct, and misc cleanup
@@ -225,7 +228,6 @@ int _handle_ready_sockets(void *p, va_list data)
   icq_TCPLink *plink=(icq_TCPLink *)p;
   ICQLINK *icqlink = plink->icqlink;
   int socket=plink->socket;
-  icq_ChatSession *pchat;
 
   (void)data;
 
@@ -250,16 +252,7 @@ int _handle_ready_sockets(void *p, va_list data)
   if(socket>-1 && FD_ISSET(socket, &icqlink->TCP_readfds))
   {
     if(plink->mode & TCP_LINK_MODE_LISTEN)
-      if (plink->type == TCP_LINK_CHAT) {
-        /* do not accept another chat connection during a handshake */
-        pchat=icq_FindChatSession(plink->icqlink, plink->id);
-        if (!pchat->blocked) {
-          pchat->blocked = 1;
-          (void)icq_TCPLinkAccept(plink);
-        }
-      } else {
-        (void)icq_TCPLinkAccept(plink);
-      }
+      (void)icq_TCPLinkAccept(plink);
     else {
 
       int result=icq_TCPLinkOnDataReceived(plink);
@@ -341,17 +334,17 @@ DWORD icq_TCPSendMessage(ICQLINK *link, DWORD uin, const char *message)
   icq_TCPLink *plink;
   icq_Packet *p;
   DWORD sequence;
-  char *data ;
-  
-  data=strdup(message) ;
-  icq_RusConv("kw", data) ;
+  char *data;
 
-  plink=icq_TCPCheckLink(link, uin, TCP_LINK_MESSAGE);
+  data = strdup(message);
+  icq_RusConv("kw", data);
+
+  plink = icq_TCPCheckLink(link, uin, TCP_LINK_MESSAGE);
 
   /* create and send the message packet */
-  p=icq_TCPCreateMessagePacket(plink, (unsigned char *)data);
+  p = icq_TCPCreateMessagePacket(plink, (unsigned char *) data);
+  sequence = icq_TCPLinkSendSeq(plink, p, 0);
   free(data);
-  sequence=icq_TCPLinkSendSeq(plink, p, 0);
 
 #ifdef TCP_PACKET_TRACE
   printf("message packet sent to uin %lu { sequence=%lx }\n", uin, p->id);
@@ -365,16 +358,16 @@ DWORD icq_TCPSendURL(ICQLINK *link, DWORD uin, const char *message, const char *
   icq_TCPLink *plink;
   icq_Packet *p;
   DWORD sequence;
-  char *data;
+  char data[512];
 
   plink=icq_TCPCheckLink(link, uin, TCP_LINK_MESSAGE);
   
-  data = strdup(message);
+  strncpy(data, message, 512);
+  data[511] = '\0';
   icq_RusConv("kw", data);
 
   /* create and send the url packet */
   p=icq_TCPCreateURLPacket(plink, data, url);
-  free(data);
   sequence=icq_TCPLinkSendSeq(plink, p, 0);
 
 #ifdef TCP_PACKET_TRACE
@@ -389,6 +382,7 @@ DWORD icq_TCPSendContact(ICQLINK *link, DWORD uin, const icqcontactmsg *contact)
   icq_TCPLink *plink;
   icq_Packet *p;
   DWORD sequence;
+  char data[512] ;
   
   plink=icq_TCPCheckLink(link, uin, TCP_LINK_MESSAGE);
 
@@ -397,98 +391,27 @@ DWORD icq_TCPSendContact(ICQLINK *link, DWORD uin, const icqcontactmsg *contact)
   sequence=icq_TCPLinkSendSeq(plink, p, 0);
 
 #ifdef TCP_PACKET_TRACE
-  printf("contact packet sent to uin %lu { sequence=%lx }\n", uin, p->id);
+  printf("message packet sent to uin %lu { sequence=%lx }\n", uin, p->id);
 #endif
 
   return sequence;
 }
 
-DWORD icq_TCPSendAuthReq(ICQLINK *link, DWORD uin, const char *nick,
-                         const char *first, const char *last,
-                         const char *email, const char *reason)
+DWORD icq_SendChatRequest(ICQLINK *link, DWORD uin, const char *message)
 {
   icq_TCPLink *plink;
   icq_Packet *p;
   DWORD sequence;
-  
-  plink=icq_TCPCheckLink(link, uin, TCP_LINK_MESSAGE);
-
-  /* create and send the auth req packet */
-  p=icq_TCPCreateAuthReqPacket(plink, nick, first, last, email, reason);
-  sequence=icq_TCPLinkSendSeq(plink, p, 0);
-
-#ifdef TCP_PACKET_TRACE
-  printf("auth request packet sent to uin %lu { sequence=%lx }\n", uin, p->id);
-#endif
-
-  return sequence;
-}
-
-DWORD icq_TCPSendAdded(ICQLINK *link, DWORD uin, const char *nick,
-                       const char *first, const char *last,
-                       const char *email)
-{
-  icq_TCPLink *plink;
-  icq_Packet *p;
-  DWORD sequence;
-  
-  plink=icq_TCPCheckLink(link, uin, TCP_LINK_MESSAGE);
-
-  /* create and send the "added" packet */
-  p=icq_TCPCreateAddedPacket(plink, nick, first, last, email);
-  sequence=icq_TCPLinkSendSeq(plink, p, 0);
-
-#ifdef TCP_PACKET_TRACE
-  printf("added packet sent to uin %lu { sequence=%lx }\n", uin, p->id);
-#endif
-
-  return sequence;
-}
-
-int _icq_AppendBuddyName(void *p, va_list data)
-{
-  char *s=va_arg(data, char *);
-  int len=va_arg(data, int);
-  icq_ChatClient *c = (icq_ChatClient *)p;
-  
-  if (c->status == CHAT_STATUS_READY
-      && strlen(c->handle)+2+strlen(s)+1 <= len) {
-    strcat(s, c->handle);
-    strcat(s, ", ");
-  }
-  
-}
-
-DWORD icq_SendChatRequest(ICQLINK *link, DWORD uin, const char *message,
-                          icq_ChatSession *session)
-{
-  icq_TCPLink *plink;
-  icq_Packet *p;
-  DWORD sequence;
-  char *data;
-  char buddies[1024];
+  char data[512];
 
   plink=icq_TCPCheckLink(link, uin, TCP_LINK_MESSAGE);
   
-  data = strdup(message);
+  strncpy(data, message, 512);
+  data[511] = '\0';
   icq_RusConv("kw", data);
 
-  if (session) {
-    /* create and send the multichat request packet */
-    buddies[0] = 0;
-    list_traverse(session->clients, _icq_AppendBuddyName, buddies, 1024);
-    if (strlen(buddies) >= 2) {
-      buddies[strlen(buddies)-2] = 0; /* strip the last comma */
-    }
-    
-    p=icq_TCPCreateChatReqPacket(plink, (unsigned char *)data, buddies,
-                                 session->listen_link->socket_address.sin_port);
-    free(data);
-  } else {
-    /* create and send the single chat request packet */
-    p=icq_TCPCreateChatReqPacket(plink, (unsigned char *)data, "", 0);
-    free(data);
-  }
+  /* create and send the url packet */
+  p=icq_TCPCreateChatReqPacket(plink, (unsigned char *)data);
   sequence=icq_TCPLinkSendSeq(plink, p, 0);
 
 #ifdef TCP_PACKET_TRACE
@@ -506,7 +429,7 @@ unsigned long icq_SendFileRequest(ICQLINK *link, unsigned long uin,
   icq_Packet *p;
   unsigned long sequence;
   char filename[64];
-  char *data;
+  char data[512];
 
   plink=icq_TCPCheckLink(link, uin, TCP_LINK_MESSAGE);
 
@@ -531,13 +454,13 @@ unsigned long icq_SendFileRequest(ICQLINK *link, unsigned long uin,
 
   strncpy(filename, *(pfile->files), 64);
 
-  data = strdup(message);
-  icq_RusConv("kw", data);
+  strncpy(data, message, 512);
+  data[511] = '\0';
+  icq_RusConv("kw", data);  
 
   /* create and send the file req packet */
   p=icq_TCPCreateFileReqPacket(plink, (char *)data, filename, 
     pfile->total_bytes);
-  free(data);
   sequence=icq_TCPLinkSendSeq(plink, p, 0);
   plink->id=pfile->id=sequence;
 
@@ -548,127 +471,78 @@ unsigned long icq_SendFileRequest(ICQLINK *link, unsigned long uin,
   return sequence;
 }            
 
-/*
-  tries to connect with another chat client and adds them to list
-*/
-void icq_ChatConnect(ICQLINK *link, icq_ChatSession *pchat, DWORD uin, unsigned long port)
-{
-  icq_ChatClient *c = icq_FindChatClient(pchat, uin);
-  icq_Packet *p2;
-  
-  /* if the client is already on the list, do nothing 
-     if not, add them and try to connect  */
-
-  if (!c) {
-    c = (icq_ChatClient *)malloc(sizeof(icq_ChatClient));
-
-    list_insert(pchat->clients, 0, c);
-    
-    c->tcplink=icq_TCPLinkNew(link);
-    c->tcplink->type=TCP_LINK_CHAT;
-    c->tcplink->id=pchat->id;
-    c->status = CHAT_STATUS_CONNECTING;
-    c->uin = uin;
-    c->port = port;
-    c->rev_port = htons(port);
-  
-    icq_TCPLinkConnect(c->tcplink, uin, port);
-    
-    c->tcplink->session=pchat;
-
-    p2=icq_TCPCreateChatInfoPacket(c->tcplink, link->icq_Nick,
-                                   0x00ffffff, 0x00000000,
-				   pchat->listen_link->socket_address.sin_port);
-    icq_TCPLinkSend(c->tcplink, p2);
-  }
-
-}
-
-/*
-  port == 0 && session != 0 ... joining requester to a running chat session
-  port != 0 && session == 0 ... we are being joined to a running chat session
-  port == 0 && session == 0 ... creating a new head to head chat
-*/
-void icq_AcceptChatRequest(ICQLINK *link, DWORD uin, unsigned long sequence, 
-                           unsigned long port, icq_ChatSession *session)
+void icq_AcceptChatRequest(ICQLINK *link, DWORD uin, unsigned long sequence)
 {
   icq_TCPLink *pmessage, *plisten;
   icq_ChatSession *pchat;
   icq_Packet *p;
 
-  if (port && session) {
-    /* we cannot merge two chat session in progress */
-    return;
-  }
-
   pmessage=icq_TCPCheckLink(link, uin, TCP_LINK_MESSAGE);
 
-  if (session) {
-    pchat = session;
-    plisten = pchat->listen_link;
-  } else {
-    /* create the chat session, this will be linked to the incoming icq_TCPLink
-     * in TCPProcessHello */ 
-    pchat=icq_ChatSessionNew(link);
-    /* create the chat listening socket */
+  /* create the chat listening socket if necessary */
+  if(!(plisten=icq_FindTCPLink(link, 0, TCP_LINK_CHAT)))
+  {
     plisten=icq_TCPLinkNew( link );
-    plisten->id = pchat->id = sequence;
     plisten->type=TCP_LINK_CHAT;
     icq_TCPLinkListen(plisten);
-    pchat->listen_link = plisten;
   }
 
+  /* create the chat session, this will be linked to the incoming icq_TCPLink
+   * in TCPProcessHello */ 
+  pchat=icq_ChatSessionNew(link);
+  pchat->id=sequence;
+  pchat->remote_uin=uin;
+
   /* create and send the ack packet */
   p=icq_TCPCreateChatReqAck(pmessage,
     ntohs(plisten->socket_address.sin_port));
   (void)icq_TCPLinkSendSeq(pmessage, p, sequence);
 
-  /* if we are joining multichat, proceed to the connection immediately */
-  if (port) {
-    icq_ChatConnect(link, pchat, uin, port);
-  }
-
 #ifdef TCP_PACKET_TRACE
   printf("chat req ack sent to uin %lu { sequence=%lx }\n", uin, sequence);
 #endif
 }
 
-/* sends supplied data to one buddy */
-int _icq_SendChatData(void *p, va_list data)
-{
-  icq_ChatClient *c=(icq_ChatClient *)p;
-  const char *s=va_arg(data, const char *);
-  int len=va_arg(data, int);
-  
-  if (c->status == CHAT_STATUS_READY) {
-    send(c->tcplink->socket, s, len, 0);
-  }
-  return 0;
-}
-
-void icq_TCPSendChatData(ICQLINK *link, icq_ChatSession *session, const char *data)
+void icq_TCPSendChatData(ICQLINK *link, DWORD uin, const char *data)
 {
+  icq_TCPLink *plink=icq_FindTCPLink(link, uin, TCP_LINK_CHAT);
   char data1[512];
   int data1_len;
 
+  if(!plink)
+    return;  
+
   strncpy(data1,data,512) ;
   data1[511] = '\0';
   data1_len = strlen(data);
   icq_ChatRusConv_n("kw", data1, data1_len);
 
-  list_traverse(session->clients, _icq_SendChatData, data1, data1_len);
+  send(plink->socket, data1, data1_len, 0);
 
 }
 
-void icq_TCPSendChatData_n(ICQLINK *link, icq_ChatSession *session, const char *data, int len)
+void icq_TCPSendChatData_n(ICQLINK *link, DWORD uin, const char *data, int len)
 {
+  icq_TCPLink *plink=icq_FindTCPLink(link, uin, TCP_LINK_CHAT);
   char *data1;
 
+  if(!plink)
+    return;
+
   data1 = (char *)malloc(len);
   memcpy(data1, data, len);
   icq_ChatRusConv_n("kw", data1, len);  
 
-  list_traverse(session->clients, _icq_SendChatData, data1, len);
+  send(plink->socket, data1, len, 0);
+
+}
+
+void icq_TCPCloseChat(ICQLINK *link, unsigned long uin)
+{
+  icq_TCPLink *plink=icq_FindTCPLink(link, uin, TCP_LINK_CHAT);
+
+  if(plink)
+    icq_TCPLinkClose(plink);
 
 }
 
@@ -681,18 +555,20 @@ icq_FileSession *icq_AcceptFileRequest(ICQLINK *link, DWORD uin,
 
   pmessage=icq_TCPCheckLink(link, uin, TCP_LINK_MESSAGE);
 
-  /* create the file listening socket */
-  plisten=icq_TCPLinkNew( link );
-  plisten->type=TCP_LINK_FILE;
-  icq_TCPLinkListen(plisten);
+  /* create the file listening socket if necessary */
+  if(!(plisten=icq_FindTCPLink(link, 0, TCP_LINK_FILE)))
+  {
+    plisten=icq_TCPLinkNew( link );
+    plisten->type=TCP_LINK_FILE;
+    icq_TCPLinkListen(plisten);
+  }
 
   /* create the file session, this will be linked to the incoming icq_TCPLink
    * in TCPProcessHello */ 
   pfile=icq_FileSessionNew(link);
-  plisten->id=pfile->id=sequence;
+  pfile->id=sequence;
   pfile->remote_uin=uin;
   pfile->direction=FILE_STATUS_RECEIVING;
-  pfile->listen_link=plisten;
   icq_FileSessionSetStatus(pfile, FILE_STATUS_LISTENING);
 
   /* create and send the ack packet */
