@@ -1,7 +1,10 @@
 /* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /*
-$Id: tcplink.c,v 1.38 2000/07/09 22:19:35 bills Exp $
+$Id: tcplink.c,v 1.1.1.1 2001/05/12 16:50:57 konst Exp $
 $Log: tcplink.c,v $
+Revision 1.1.1.1  2001/05/12 16:50:57  konst
+Imported into the CVS repository
+
 Revision 1.38  2000/07/09 22:19:35  bills
 added new *Close functions, use *Close functions instead of *Delete
 where correct, and misc cleanup
@@ -237,13 +240,9 @@ void icq_TCPLinkDelete(void *pv)
   {
     if(p->type==TCP_LINK_CHAT)
     {
-      if (p->remote_uin) {
-        icq_ChatSessionBuddyLinkClosed(p->session, p->remote_uin);
-      } else {
-        icq_ChatSession *psession=p->session;
-        psession->listen_link=0L;
-        icq_ChatSessionClose(psession);
-      }
+      icq_ChatSession *psession=p->session;
+      /*psession->tcplink=0L;*/
+      icq_ChatSessionClose(psession);
     }
 
     if(p->type==TCP_LINK_FILE) {
@@ -268,8 +267,9 @@ void icq_TCPLinkDelete(void *pv)
 
 void icq_TCPLinkClose(icq_TCPLink *plink)
 {
-  list_remove(plink->icqlink->icq_TCPLinks, plink);
-  icq_TCPLinkDelete(plink);
+  if(list_remove(plink->icqlink->icq_TCPLinks, plink)) {
+    icq_TCPLinkDelete(plink);
+  }
 }
 
 int icq_TCPLinkProxyConnect(icq_TCPLink *plink, DWORD uin, int port)
@@ -617,23 +617,19 @@ icq_TCPLink *icq_TCPLinkAccept(icq_TCPLink *plink)
   
   if(pnewlink)
   {
-		socket=accept(plink->socket, (struct sockaddr *)&(plink->remote_address),
+                socket=accept(plink->socket, (struct sockaddr *)&(plink->remote_address),
                   &remote_length);
 
-		icq_FmtLog(plink->icqlink, ICQ_LOG_MESSAGE,
-			"accepting tcp connection from %s:%d\n",
-			inet_ntoa(*((struct in_addr *)(&(plink->remote_address.sin_addr)))),
-			ntohs(plink->remote_address.sin_port));
+                icq_FmtLog(plink->icqlink, ICQ_LOG_MESSAGE,
+                        "accepting tcp connection from %s:%d\n",
+                        inet_ntoa(*((struct in_addr *)(&(plink->remote_address.sin_addr)))),
+                        ntohs(plink->remote_address.sin_port));
 
-		/* FIXME: make sure accept succeeded */
+                /* FIXME: make sure accept succeeded */
 
     pnewlink->type=plink->type;
     pnewlink->socket=socket;
 
-    /* this appears necessary for multichat */
-    pnewlink->id=plink->id;
-    pnewlink->session=plink->session;
-
     /* first packet sent on an icq tcp link is always the hello packet */
     pnewlink->mode|=TCP_LINK_MODE_HELLOWAIT;
   }
@@ -781,6 +777,7 @@ int icq_TCPLinkOnDataReceived(icq_TCPLink *plink)
         icq_FmtLog(plink->icqlink, ICQ_LOG_WARNING, "tcplink buffer "
           "overflow, packet size = %d, buffer size = %d, closing link\n",
           packet_size, icq_TCPLinkBufferSize);
+//        icq_TCPLinkClose(plink);
         return 0;
       }
 
@@ -910,9 +907,9 @@ void icq_TCPLinkOnConnect(icq_TCPLink *plink)
   if(plink->type==TCP_LINK_CHAT)
   {
     icq_ChatSessionSetStatus((icq_ChatSession *)plink->session,
-      plink->remote_uin, CHAT_STATUS_CONNECTED);
+      CHAT_STATUS_CONNECTED);
     icq_ChatSessionSetStatus((icq_ChatSession *)plink->session, 
-      plink->remote_uin, CHAT_STATUS_WAIT_ALLINFO);
+      CHAT_STATUS_WAIT_ALLINFO);
   }
 
   if(plink->type==TCP_LINK_FILE)
@@ -926,12 +923,6 @@ void icq_TCPLinkOnConnect(icq_TCPLink *plink)
 unsigned long icq_TCPLinkSendSeq(icq_TCPLink *plink, icq_Packet *p,
   unsigned long sequence)
 {
-  /* is this a valid packet ? */
-  if (p->invalid) {
-    icq_FmtLog(plink->icqlink, ICQ_LOG_FATAL, "TCPLinkSendSeq: invalid packed encountered\n");
-    return 0;
-  }
-
   /* append the next sequence number on the packet */
   if (!sequence)
     sequence=plink->icqlink->icq_TCPSequence--;
