@@ -1,7 +1,10 @@
 /* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /*
-$Id: udp.c,v 1.23 2000/07/09 22:19:35 bills Exp $
+$Id: udp.c,v 1.1.1.1 2001/05/12 16:50:57 konst Exp $
 $Log: udp.c,v $
+Revision 1.1.1.1  2001/05/12 16:50:57  konst
+Imported into the CVS repository
+
 Revision 1.23  2000/07/09 22:19:35  bills
 added new *Close functions, use *Close functions instead of *Delete
 where correct, and misc cleanup
@@ -503,19 +506,6 @@ void icq_Logout(ICQLINK *link) /* V5 */
   icq_PacketDelete(p);
 }
 
-/*************************************************
-Tells the server that we have trouble connecting
-**************************************************/
-void icq_MessageAck(ICQLINK *link) /* V5 */
-{
-  icq_Packet *p = icq_UDPCreateStdSeqPacket(link, UDP_CMD_SEND_TEXT_CODE, 0);
-  icq_PacketAppendString(p, "B_MESSAGE_ACK");
-  icq_PacketAppend8(p, 5);
-  icq_PacketAppend8(p, 0);
-  icq_UDPSockWrite(link, p);
-  icq_PacketDelete(p);
-}
-
 /*******************************
 This routine sends the aknowlegement cmd to the
 server it appears that this must be done after
@@ -537,23 +527,17 @@ message to send.
 ***************************************************/
 WORD icq_UDPSendMessage(ICQLINK *link, DWORD uin, const char *text) /* V5 */
 {
-  char *buf; /* message may be only 450 bytes long */
+  char buf[512]; /* message may be only 450 bytes long */
   icq_Packet *p;
 
-  buf = strdup(text);
+  strncpy(buf, text, 512);
   icq_RusConv("kw", buf);
 
   p = icq_UDPCreateStdPacket(link, UDP_CMD_SEND_THRU_SRV);
   icq_PacketAppend32(p, uin);
   icq_PacketAppend16(p, TYPE_MSG);
   icq_PacketAppendString(p, buf);
-  free(buf);
 
-  if (p->invalid || p->length > 450) {
-    icq_PacketDelete(p);
-    return 0;
-  }
-  
   icq_UDPSockWrite(link, p);
   icq_PacketDelete(p);
   return link->icq_UDPSeqNum1-1;
@@ -561,25 +545,20 @@ WORD icq_UDPSendMessage(ICQLINK *link, DWORD uin, const char *text) /* V5 */
 
 WORD icq_UDPSendURL(ICQLINK *link, DWORD uin, const char *url, const char *descr) /* V5 */
 {
-  char *buf1, *buf2;
+  char buf1[512], buf2[512];
   icq_Packet *p;
 
-  buf1 = strdup(descr);
+  strncpy(buf1, descr, 512);
   icq_RusConv("kw", buf1);
+  strncpy(buf2, url, 512);
 
   p = icq_UDPCreateStdPacket(link, UDP_CMD_SEND_THRU_SRV);
   icq_PacketAppend32(p, uin);
   icq_PacketAppend16(p, TYPE_URL);
-  icq_PacketAppend16(p, strlen(buf1)+strlen(url)+2); /* length + the NULL + 0xFE delimiter */
+  icq_PacketAppend16(p, strlen(buf1)+strlen(buf2)+2); /* length + the NULL + 0xFE delimiter */
   icq_PacketAppendStringFE(p, buf1);
-  icq_PacketAppendString0(p, url);
-  free(buf1);
-  
-  if (p->invalid || p->length > 450) {
-    icq_PacketDelete(p);
-    return 0;
-  }
-  
+  icq_PacketAppendString0(p, buf2);
+
   icq_UDPSockWrite(link, p);
   icq_PacketDelete(p);
   return link->icq_UDPSeqNum1-1;
@@ -594,14 +573,13 @@ WORD icq_UDPSendContact(ICQLINK *link, DWORD uin, const icqcontactmsg *contact)
 
   const icqcontactmsg *citem;
 
-  cnt = 0;
   citem = contact;
   while (citem) {
     cnt++;
     citem = citem->next;
   }
 
-  if (cnt > MAX_UDP_CONTACT_COUNT) cnt = MAX_UDP_CONTACT_COUNT;
+  if (cnt > 15) cnt = 15;
   
   citem = contact;
   sprintf(buf, "%d\xFE", cnt);
@@ -619,85 +597,6 @@ WORD icq_UDPSendContact(ICQLINK *link, DWORD uin, const icqcontactmsg *contact)
   icq_PacketAppend16(p, TYPE_CONTACT);
   icq_PacketAppendString(p, buf);
 
-  if (p->invalid || p->length > 450) {
-    icq_PacketDelete(p);
-    return 0;
-  }
-  
-  icq_UDPSockWrite(link, p);
-  icq_PacketDelete(p);
-  return link->icq_UDPSeqNum1-1;
-}
-
-WORD icq_UDPSendAuthReq(ICQLINK *link, DWORD uin, const char *nick, const char *first,
-		        const char *last, const char *email, const char *reason) /* V5 */
-{
-  char *buf1, *buf2, *buf3, *buf4, *buf5;
-  icq_Packet *p;
-
-  buf1 = strdup(nick);
-  buf2 = strdup(first);
-  buf3 = strdup(last);
-  buf4 = strdup(email);
-  buf5 = strdup(reason);
-  icq_RusConv("kw", buf1);
-  icq_RusConv("kw", buf2);
-  icq_RusConv("kw", buf3);
-  icq_RusConv("kw", buf4);
-  icq_RusConv("kw", buf5);
-
-  p = icq_UDPCreateStdPacket(link, UDP_CMD_SEND_THRU_SRV);
-  icq_PacketAppend32(p, uin);
-  icq_PacketAppend16(p, TYPE_AUTH);
-  icq_PacketAppend16(p, strlen(buf1)+strlen(buf2)+strlen(buf3)+strlen(buf4)+strlen(buf5)+6);
-  icq_PacketAppendStringFE(p, buf1);
-  icq_PacketAppendStringFE(p, buf2);
-  icq_PacketAppendStringFE(p, buf3);
-  icq_PacketAppendStringFE(p, buf4);
-  icq_PacketAppendStringFE(p, "");
-  icq_PacketAppendString0(p, buf5);
-  free(buf1);
-  
-  if (p->invalid || p->length > 450) {
-    icq_PacketDelete(p);
-    return 0;
-  }
-  
-  icq_UDPSockWrite(link, p);
-  icq_PacketDelete(p);
-  return link->icq_UDPSeqNum1-1;
-}
-
-WORD icq_UDPSendAdded(ICQLINK *link, DWORD uin, const char *nick, const char *first,
-		      const char *last, const char *email) /* V5 */
-{
-  char *buf1, *buf2, *buf3, *buf4, *buf5;
-  icq_Packet *p;
-
-  buf1 = strdup(nick);
-  buf2 = strdup(first);
-  buf3 = strdup(last);
-  buf4 = strdup(email);
-  icq_RusConv("kw", buf1);
-  icq_RusConv("kw", buf2);
-  icq_RusConv("kw", buf3);
-  icq_RusConv("kw", buf4);
-
-  p = icq_UDPCreateStdPacket(link, UDP_CMD_SEND_THRU_SRV);
-  icq_PacketAppend32(p, uin);
-  icq_PacketAppend16(p, TYPE_ADDED);
-  icq_PacketAppend16(p, strlen(buf1)+strlen(buf2)+strlen(buf3)+strlen(buf4)+4);
-  icq_PacketAppendStringFE(p, buf1);
-  icq_PacketAppendStringFE(p, buf2);
-  icq_PacketAppendStringFE(p, buf3);
-  icq_PacketAppendString0(p, buf4);
-  free(buf1);
-  
-  if (p->invalid || p->length > 450) {
-    icq_PacketDelete(p);
-    return 0;
-  }
-  
   icq_UDPSockWrite(link, p);
   icq_PacketDelete(p);
   return link->icq_UDPSeqNum1-1;
@@ -834,11 +733,7 @@ WORD icq_UpdateUserInfo(ICQLINK *link, const char *nick, const char *first, cons
 WORD icq_UpdateAuthInfo(ICQLINK *link, DWORD auth) /* V5 */
 {
   icq_Packet *p = icq_UDPCreateStdPacket(link, UDP_CMD_UPDATE_AUTH);
-  if (auth) {
-    icq_PacketAppend32(p, 1); /* don't request */
-  } else {
-    icq_PacketAppend32(p, 0); /* request */
-  }    
+  icq_PacketAppend32(p, auth); /* NOT auth? */
   icq_UDPSockWrite(link, p);
   icq_PacketDelete(p);
   return link->icq_UDPSeqNum1-1;
@@ -848,7 +743,7 @@ WORD icq_UpdateMetaInfoSet(ICQLINK *link, const char *nick, const char *first, c
                            const char *email, const char *email2, const char *email3,
                            const char *city, const char *state, const char *phone, const char *fax,
                            const char *street, const char *cellular, unsigned long zip,
-                           unsigned short cnt_code, unsigned char timezone, unsigned char no_auth)
+                           unsigned short cnt_code, unsigned char cnt_stat, unsigned char emailhide)
 {
   icq_Packet *p = icq_UDPCreateStdPacket(link, UDP_CMD_META_USER);
   icq_PacketAppend16(p, META_CMD_SET_INFO);
@@ -866,8 +761,8 @@ WORD icq_UpdateMetaInfoSet(ICQLINK *link, const char *nick, const char *first, c
   icq_PacketAppendString(p, cellular);
   icq_PacketAppend32(p, zip);
   icq_PacketAppend16(p, cnt_code);
-  icq_PacketAppend8(p, timezone);
-  icq_PacketAppend8(p, no_auth);
+  icq_PacketAppend8(p, cnt_stat);
+  icq_PacketAppend8(p, emailhide);
   icq_UDPSockWrite(link, p);
   icq_PacketDelete(p);
   return link->icq_UDPSeqNum2-1;
@@ -921,16 +816,6 @@ WORD icq_UpdateMetaInfoSecurity(ICQLINK *link, unsigned char reqauth, unsigned c
   return link->icq_UDPSeqNum2-1;
 }
 
-WORD icq_UpdateMetaInfoPass(ICQLINK *link, const char* pass)
-{
-  icq_Packet *p = icq_UDPCreateStdPacket(link, UDP_CMD_META_USER);
-  icq_PacketAppend16(p, META_CMD_SET_PASS);
-  icq_PacketAppendString(p, pass);
-  icq_UDPSockWrite(link, p);
-  icq_PacketDelete(p);
-  return link->icq_UDPSeqNum2-1;
-}
-
 WORD icq_UpdateNewUserInfo(ICQLINK *link, const char *nick, const char *first, const char *last,
                            const char *email) /* V5 */
 {
