@@ -13,11 +13,7 @@
 #include "konst.conf.h"
 #include "konst.string.h"
 
-#if !defined(__FreeBSD__) && !defined(__OpenBSD__)
-
-#include <ftw.h>
-
-#else
+#if defined(__FreeBSD__) || defined(__OpenBSD__) || defined(__NetBSD__)
 
 #define FTW_F           1
 #define FTW_D           2
@@ -30,6 +26,10 @@
 #define nftw(d, f, de, fl)      stubnftw(d, f, de, fl)
 #define ftw(d, f, de)           stubnftw(d, f, de, 0)
 
+#else
+
+#include <ftw.h>
+
 #endif
 
 __KTOOL_BEGIN_NAMESPACE
