@@ -690,5 +690,14 @@ void icqcontact::incinfotryn() {
 }
 
 bool icqcontact::operator > (const icqcontact &acontact) const {
-    return acontact.lastread > lastread;
+    if(acontact.lastread != lastread) return acontact.lastread > lastread;
+    else return acontact.uin > uin;
+}
+
+void icqcontact::setpostponed(const string apostponed) {
+    postponed = apostponed;
+}
+
+string icqcontact::getpostponed() {
+    return postponed;
 }
