@@ -9,6 +9,7 @@
 #include "icqoffline.h"
 
 #include "konst.socket.h"
+#include <regex.h>
 
 const char *stryesno(bool i) {
     return i ? _("yes") : _("no");
@@ -68,6 +69,12 @@ string getbdate(unsigned char bday, unsigned char bmonth, unsigned char byear) {
 icqface::icqface(): mainscreenblock(false), inited(false), onlinefolder(false) {
     kinterface();
     workareas.freeitem = &freeworkareabuf;
+
+#ifdef DEBUG
+    time_t logtime = time(0);
+    flog.open(((string) getenv("HOME") + "/.centericq/log").c_str(), _IO_APPEND);
+    if(flog.is_open()) flog << endl << "-- centericq log started on " << ctime(&logtime);
+#endif
 }
 
 icqface::~icqface() {
@@ -75,6 +82,10 @@ icqface::~icqface() {
     if(inited) {
 	for(int i = 0; i < LINES; i++) printf("\n");
     }
+
+#ifdef DEBUG
+    if(flog.is_open()) flog.close();
+#endif
 }
 
 void icqface::init() {
@@ -119,18 +130,19 @@ void icqface::draw() {
 }
 
 void icqface::showtopbar() {
-    string st =
-	_("STATUS: ") + textstatus(icql.icq_Status) + "  " +
-	_("UNSENT: ") + i2str(offl.getunsentcount());
-
-    string suin = i2str(icql.icq_Uin);
-
     attrset(conf.getcolor(cp_status));
     mvhline(0, 0, ' ', COLS);
 
-    kwriteatf(2, 0, conf.getcolor(cp_status), "CENTERICQ %s", VERSION);
-    kwriteatf(20, 0, conf.getcolor(cp_status), "%s", st.c_str());
-    kwriteatf(COLS-suin.size()-1, 0, conf.getcolor(cp_status), "%s", suin.c_str());
+    string spadd(COLS-strlen(VERSION)-textstatus(icql.icq_Status).size()-
+	i2str(offl.getunsentcount()).size()-i2str(icql.icq_Uin).size()-
+	32, ' ');
+
+    kwriteatf(0, 0, conf.getcolor(cp_status),
+	" CENTERICQ %s  STATUS: %s  UNSENT: %lu%s%lu ",
+	    VERSION,
+	    textstatus(icql.icq_Status).c_str(),
+	    offl.getunsentcount(),
+	    spadd.c_str(), icql.icq_Uin);
 }
 
 void icqface::update() {
@@ -480,6 +492,24 @@ void icqface::infoclear(dialogbox &db, icqcontact *c, unsigned int uin) {
 
     workarealine(WORKAREA_Y1+2);
     workarealine(WORKAREA_Y2-2);
+
+    string fhomepage1, fhomepage2, fcity, fstate, fphone, ffax, fstreet,
+	fcellular, fcompany, fdepartment, fjob, buf;
+    unsigned char fage, flang1, flang2, flang3, fbday, fbmonth, fbyear,
+	fgender;
+    unsigned short fcountry, foccupation;
+    unsigned long fzip;
+
+    c->getmoreinfo(fage, fgender, fhomepage1, flang1, flang2, flang3, fbday, fbmonth, fbyear);
+    c->getworkinfo(fcity, fstate, fphone, ffax, fstreet, fzip, fcountry, fcompany, fdepartment, fjob, foccupation, fhomepage2);
+
+    buf = " " + fcity + " " + fstate + " " + fstreet + " " +
+	fcompany + " " + fdepartment + " " + fjob + " " +
+	c->getabout();
+
+    extracturls(buf);
+    if(!fhomepage1.empty()) extractedurls.push_back(fhomepage1);
+    if(!fhomepage2.empty()) extractedurls.push_back(fhomepage2);
 }
 
 void icqface::infogeneral(dialogbox &db, icqcontact *c) {
@@ -535,11 +565,11 @@ void icqface::infogeneral(dialogbox &db, icqcontact *c) {
     mainw.write(WORKAREA_X1+14, WORKAREA_Y1+13, conf.getcolor(cp_main_text), c->getlastip());
 
     if(c->getstatus() == STATUS_OFFLINE) {
-	char buf[64];
 	time_t ls = c->getlastseen();
 
 	mainw.write(WORKAREA_X1+2, WORKAREA_Y1+14, conf.getcolor(cp_main_highlight), _("Last seen"));
-	mainw.write(WORKAREA_X1+14, WORKAREA_Y1+14, conf.getcolor(cp_main_text), ls ? time2str(&ls, "DD.MM.YY hh:mm", buf) : _("Never"));
+	mainw.write(WORKAREA_X1+14, WORKAREA_Y1+14, conf.getcolor(cp_main_text),
+	    ls ? strdateandtime(ls) : _("Never"));
     }
 }
 
@@ -655,7 +685,7 @@ void icqface::infowork(dialogbox &db, icqcontact *c) {
 }
 
 void icqface::infoabout(dialogbox &db, icqcontact *c) {
-    db.getbrowser()->setbuf(c->getabout().c_str());
+    db.getbrowser()->setbuf(c->getabout());
 }
 
 void commacat(string &text, string sub, bool nocomma = false) {
@@ -715,7 +745,7 @@ void icqface::infointerests(dialogbox &db, icqcontact *c) {
 	}
     }
 
-    db.getbrowser()->setbuf(text.c_str());
+    db.getbrowser()->setbuf(text);
 }
 
 void icqface::userinfo(unsigned int uin, bool nonicq, unsigned int realuin) {
@@ -729,6 +759,8 @@ void icqface::userinfo(unsigned int uin, bool nonicq, unsigned int realuin) {
     saveworkarea();
     clearworkarea();
 
+    status(_("F2 to URLs, ESC close"));
+
     db.setwindow(new textwindow(WORKAREA_X1, WORKAREA_Y1+2, WORKAREA_X2+1,
 	WORKAREA_Y2, conf.getcolor(cp_main_text), TW_NOBORDER));
     db.setbar(new horizontalbar(WORKAREA_X1+2, WORKAREA_Y2-1,
@@ -736,6 +768,7 @@ void icqface::userinfo(unsigned int uin, bool nonicq, unsigned int realuin) {
 	_("Info"), _("Home"), _("Work"), _("More"), _("About"),
 	!nonicq ? _("Retrieve") : _("Edit"), 0));
     db.idle = &dialogidle;
+    db.otherkeys = &userinfokeys;
 
     while(!finished) {
 	if(!showinfo) {
@@ -1021,7 +1054,7 @@ bool icqface::editurl(unsigned int uin, string &url, string &text) {
 	passuin = uin;
 	status(_("Ctrl-X send, Ctrl-P multiple, Ctrl-O history, Alt-? details, ESC cancel"));
 
-	se->load(text.c_str(), strdup(""));
+	se->load(text, strdup(""));
 	se->open();
 
 	if(editdone) {
@@ -1042,12 +1075,18 @@ bool icqface::editurl(unsigned int uin, string &url, string &text) {
 
     restoreworkarea();
     status("");
+
+    int i;
+    while((i = url.find("")) != -1)
+	url.replace(i, 1, ".");
+
     return editdone;
 }
 
 bool icqface::editmsg(unsigned int uin, string &text) {
     char *ctext;
     texteditor *se = new texteditor;
+    icqcontact *c = clist.get(uin);
 
     editdone = false;
     saveworkarea();
@@ -1070,12 +1109,13 @@ bool icqface::editmsg(unsigned int uin, string &text) {
     se->idle = &editidle;
     se->wrap = true;
 
-    se->load(text.c_str(), strdup(""));
+    se->load(text.empty() ? c->getpostponed() : text, strdup(""));
     se->open();
     ctext = se->save("\r\n");
     text = ctext;
 
     if(muins.empty()) muins.push_back(uin);
+    c->setpostponed(editdone ? "" : text);
 
     delete se;
     delete ctext;
@@ -1087,7 +1127,6 @@ bool icqface::editmsg(unsigned int uin, string &text) {
 
 bool icqface::checkicqmessage(unsigned int uin, string text, bool &ret, int options) {
     bool proceed = true, fin;
-    icqcontact *cn;
     char c;
     int i;
 
@@ -1108,9 +1147,7 @@ bool icqface::checkicqmessage(unsigned int uin, string text, bool &ret, int opti
 		cicq.userinfo(uin);
 		break;
 	    case 1:
-		clist.add(cn = new icqcontact(uin));
-		cn->setnick(i2str(uin));
-		cn->setseq2(icq_SendMetaInfoReq(&icql, uin));
+		if(!clist.get(uin)) clist.addnew(uin, false);
 		log(_("+ %lu has been added to the list"), uin);
 		break;
 	    case 2:
@@ -1143,6 +1180,7 @@ int icqface::showicq(unsigned int uin, string text, char imt, int options = 0) {
     db.setwindow(new textwindow(WORKAREA_X1, WORKAREA_Y1+2, WORKAREA_X2,
 	WORKAREA_Y2, conf.getcolor(cp_main_text), TW_NOBORDER));
     db.setbrowser(new textbrowser(conf.getcolor(cp_main_text)));
+    db.idle = &dialogidle;
 
     if(imt == ICQM_REQUEST) {
 	mainw.writef(WORKAREA_X1+2, WORKAREA_Y1, conf.getcolor(cp_main_highlight),
@@ -1152,6 +1190,8 @@ int icqface::showicq(unsigned int uin, string text, char imt, int options = 0) {
 	    conf.getcolor(cp_main_selected),
 	    _("Details"), _("Add to the list"), _("Accept"),
 	    hist ? _("Ok") : _("Ignore"), 0));
+
+	db.getbar()->item = hist ? 3 : 2;
     } else if(imt == ICQM_ADDED) {
 	mainw.writef(WORKAREA_X1+2, WORKAREA_Y1, conf.getcolor(cp_main_highlight),
 	    _("You were added to %lu's list"), uin);
@@ -1160,16 +1200,17 @@ int icqface::showicq(unsigned int uin, string text, char imt, int options = 0) {
 	    conf.getcolor(cp_main_selected), 
 	    _("Details"), _("Add to the list"),
 	    hist ? _("Ok") : _("Next"), 0));
+
+	db.getbar()->item = hist ? 2 : 1;
     }
 
     if(db.getbar()) {
-	db.getbar()->item = hist ? 3 : 2;
 	db.redraw();
 
 	workarealine(WORKAREA_Y1+2);
 	workarealine(WORKAREA_Y2-2);
 
-	db.getbrowser()->setbuf(text.c_str());
+	db.getbrowser()->setbuf(text);
 	if(!db.open(i, b)) b = -1;
 	db.close();
     }
@@ -1215,13 +1256,20 @@ bool icqface::showevent(unsigned int uin, int direction, time_t &lastread) {
 	case EVT_URL:
 	    hist.geturl(url, text);
 	    i = showurl(uin, url, text, *localtime(&lastread), tm, dir, direction & HIST_HISTORYMODE);
+
 	    switch(i) {
-		case -1: ret = false; break;
+		case -1:
+		    ret = false;
+		    break;
 		case 0:
+		    conf.openurl(url);
+		    break;
+		case 1:
 		    text = url + "\n\n" + text;
 		    cicq.fwdmsg(dir == HIST_MSG_IN ? uin : icql.icq_Uin, text);
 		    break;
-		case 1: break;
+		case 2:
+		    break;
 	    }
 	    break;
 	case EVT_FILE:
@@ -1255,6 +1303,8 @@ struct tm &senttm, int inout = HIST_MSG_IN, bool inhistory = false) {
 
     saveworkarea();
     clearworkarea();
+    extracturls(text);
+    status(_("F2 to URLs, ESC close"));
 
     db.setwindow(new textwindow(WORKAREA_X1, WORKAREA_Y1+3, WORKAREA_X2,
 	WORKAREA_Y2, conf.getcolor(cp_main_text), TW_NOBORDER));
@@ -1270,23 +1320,24 @@ struct tm &senttm, int inout = HIST_MSG_IN, bool inhistory = false) {
     }
 
     if(inout == HIST_MSG_IN) {
-	char srecv[64], ssent[64];
-
 	mainw.writef(WORKAREA_X1+2, WORKAREA_Y1, conf.getcolor(cp_main_highlight),
 	_("Message from %s, %lu"), c->getdispnick().c_str(), uin);
 
 	mainw.writef(WORKAREA_X1+2, WORKAREA_Y1+1,
 	    conf.getcolor(cp_main_highlight), _("%s, rcvd on %s"),
-	    time2str(&(t = mktime(&senttm)), "DD.MM.YY hh:mm", ssent),
-	    time2str(&(t = mktime(&recvtm)), "DD.MM.YY hh:mm", srecv));
+	    strdateandtime(&senttm).c_str(), strdateandtime(&recvtm).c_str());
     } else {
-	mainw.writef(WORKAREA_X1+2, WORKAREA_Y1, conf.getcolor(cp_main_highlight),
-	_("Message to %s, %lu"), c->getdispnick().c_str(), uin);
+	mainw.writef(WORKAREA_X1+2, WORKAREA_Y1,
+	    conf.getcolor(cp_main_highlight),
+	    _("Message to %s, %lu"),
+	    c->getdispnick().c_str(), uin);
 
-	mainw.writef(WORKAREA_X1+2, WORKAREA_Y1+1, conf.getcolor(cp_main_highlight),
-	_("Sent on %s"), time2str(&(t = mktime(&recvtm)), "DD.MM.YY hh:mm", buf));
+	mainw.writef(WORKAREA_X1+2, WORKAREA_Y1+1,
+	    conf.getcolor(cp_main_highlight),
+	    _("Sent on %s"), strdateandtime(&recvtm).c_str());
     }
 
+    db.otherkeys = &userinfokeys;
     db.idle = &dialogidle;
     db.setbrowser(new textbrowser(conf.getcolor(cp_main_text)));
     db.redraw();
@@ -1294,7 +1345,7 @@ struct tm &senttm, int inout = HIST_MSG_IN, bool inhistory = false) {
     workarealine(WORKAREA_Y1+3);
     workarealine(WORKAREA_Y2-2);
 
-    db.getbrowser()->setbuf(text.c_str());
+    db.getbrowser()->setbuf(text);
     if(!db.open(i, b)) b = -1;
     db.close();
 
@@ -1318,32 +1369,35 @@ bool inhistory = false) {
 	WORKAREA_Y2, conf.getcolor(cp_main_text), TW_NOBORDER));
 
     if(inout == HIST_MSG_IN) {
-	mainw.writef(WORKAREA_X1+2, WORKAREA_Y1, conf.getcolor(cp_main_highlight),
-	_("URL from %s, %lu"), c->getdispnick().c_str(), uin);
+	mainw.writef(WORKAREA_X1+2, WORKAREA_Y1,
+	    conf.getcolor(cp_main_highlight),
+	    _("URL from %s, %lu"), c->getdispnick().c_str(), uin);
 
-	mainw.writef(WORKAREA_X1+2, WORKAREA_Y1+1, conf.getcolor(cp_main_highlight), _("%s, rcvd on %s"),
-	time2str(&(t = mktime(&recvtm)), "DD.MM.YY hh:mm", buf),
-	time2str(&(t = mktime(&senttm)), "DD.MM.YY hh:mm", buf));
+	mainw.writef(WORKAREA_X1+2, WORKAREA_Y1+1,
+	    conf.getcolor(cp_main_highlight), _("%s, rcvd on %s"),
+	    strdateandtime(&recvtm).c_str(),
+	    strdateandtime(&senttm).c_str());
     } else {
-	mainw.writef(WORKAREA_X1+2, WORKAREA_Y1, conf.getcolor(cp_main_highlight),
-	_("URL to %s, %lu"), c->getdispnick().c_str(), uin);
+	mainw.writef(WORKAREA_X1+2, WORKAREA_Y1,
+	    conf.getcolor(cp_main_highlight),
+	    _("URL to %s, %lu"), c->getdispnick().c_str(), uin);
 
-	mainw.writef(WORKAREA_X1+2, WORKAREA_Y1+1, conf.getcolor(cp_main_highlight),
-	_("Sent on %s"), time2str(&(t = mktime(&recvtm)), "DD.MM.YY hh:mm", buf));
+	mainw.writef(WORKAREA_X1+2, WORKAREA_Y1+1,
+	    conf.getcolor(cp_main_highlight),
+	    _("Sent on %s"), strdateandtime(&recvtm).c_str());
     }
 
     mainw.write(WORKAREA_X1+2, WORKAREA_Y1+3, conf.getcolor(cp_main_text), url);
 
     if(inhistory || (!inhistory && !c->getmsgcount())) {
 	db.setbar(new horizontalbar(conf.getcolor(cp_main_highlight),
-	    conf.getcolor(cp_main_selected), _("Fwd"), _("Done"), 0));
-	db.getbar()->item = 1;
+	    conf.getcolor(cp_main_selected), _("Open"), _("Fwd"), _("Done"), 0));
     } else {
 	db.setbar(new horizontalbar(conf.getcolor(cp_main_highlight),
-	    conf.getcolor(cp_main_selected), _("Fwd"), _("Next"), 0));
-	db.getbar()->item = 1;
+	    conf.getcolor(cp_main_selected), _("Open"), _("Fwd"), _("Next"), 0));
     }
 
+    db.getbar()->item = 2;
     db.idle = &dialogidle;
     db.setbrowser(new textbrowser(conf.getcolor(cp_main_text)));
     db.redraw();
@@ -1352,7 +1406,7 @@ bool inhistory = false) {
     workarealine(WORKAREA_Y1+5);
     workarealine(WORKAREA_Y2-2);
 
-    db.getbrowser()->setbuf(text.c_str());
+    db.getbrowser()->setbuf(text);
     if(!db.open(i, b)) b = -1;
     db.close();
     restoreworkarea();
@@ -1390,7 +1444,7 @@ bool inhistory = false) {
     workarealine(WORKAREA_Y2-2);
 
     db.idle = &dialogidle;
-    db.getbrowser()->setbuf(fname.c_str());
+    db.getbrowser()->setbuf(fname);
     if(!db.open(i, b)) b = -1;
     db.close();
 
@@ -1495,15 +1549,19 @@ void icqface::refusefile(unsigned int uin, unsigned long seq) {
 }
 
 void icqface::history(unsigned int uin) {
-    int k, savepos, b;
+    int k, savepos, b, n, i;
     icqcontact *c = clist.get(uin);
     dialogbox db;
+    static string sub;
+    time_t lr;
 
     db.setwindow(new textwindow(WORKAREA_X1, WORKAREA_Y1+2, WORKAREA_X2,
 	WORKAREA_Y2, conf.getcolor(cp_main_text), TW_NOBORDER));
     db.setmenu(new verticalmenu(conf.getcolor(cp_main_text),
 	conf.getcolor(cp_main_selected)));
+
     db.idle = &dialogidle;
+    db.otherkeys = &historykeys;
 
     hist.fillmenu(uin, db.getmenu());
 
@@ -1522,11 +1580,30 @@ void icqface::history(unsigned int uin) {
 	    _("ICQ system messages history"));
 	}
 
-	while(db.open(k, b)) {
-	    int n = (int) db.getmenu()->getref(k-1);
-	    time_t lr;
-	    hist.setpos(n);
-	    showevent(uin, HIST_MSG_IN | HIST_MSG_OUT | HIST_HISTORYMODE, lr);
+	while(1) {
+	    status(_("S search, L again, ESC cancel"));
+	    if(!db.open(k, b)) break;
+	    n = (int) db.getmenu()->getref(db.getmenu()->getpos());
+
+	    if(k <= -2) {
+		if(k == -2) sub = face.inputstr(_("search for: "), sub);
+
+		if(!sub.empty()) {
+		    if((n = hist.find(sub, savepos = n)) != -1) {
+			for(i = k-1; i < db.getmenu()->getcount(); i++)
+			if((int) db.getmenu()->getref(i) == n) {
+			    db.getmenu()->setpos(i);
+			    break;
+			}
+		    } else {
+			log(_("+ search string not found"));
+			hist.setpos(savepos);
+		    }
+		}
+	    } else {
+		hist.setpos(n);
+		showevent(uin, HIST_MSG_IN | HIST_MSG_OUT | HIST_HISTORYMODE, lr);
+	    }
 	}
 
 	hist.closecontact();
@@ -1646,6 +1723,7 @@ bool icqface::multicontacts(string head, list<unsigned int> &lst) {
     unsigned int ffuin;
     bool ret = true, finished = false;
     list<unsigned int>::iterator c;
+    list<unsigned int> mlst;
 
     verticalmenu m(WORKAREA_X1+1, WORKAREA_Y1+3, WORKAREA_X2, WORKAREA_Y2,
 	conf.getcolor(cp_main_text), conf.getcolor(cp_main_selected));
@@ -1658,6 +1736,11 @@ bool icqface::multicontacts(string head, list<unsigned int> &lst) {
     if(!head.size()) head = _("Event recipients");
     mainw.write(WORKAREA_X1+2, WORKAREA_Y1, conf.getcolor(cp_main_highlight), head);
 
+    for(i = 0; i < clist.count; i++) {
+	icqcontact *c = (icqcontact *) clist.at(i);
+	if(c->getuin()) mlst.push_back(c->getuin());
+    }
+
     m.idle = &menuidle;
     m.otherkeys = &multiplekeys;
 
@@ -1665,13 +1748,12 @@ bool icqface::multicontacts(string head, list<unsigned int> &lst) {
 	m.getpos(saveelem, savefirst);
 	m.clear();
 
-	for(i = 0; i < clist.count; i++) {
-	    icqcontact *c = (icqcontact *) clist.at(i);
+	for(c = mlst.begin(); c != mlst.end(); c++) {
+	    icqcontact *cont = (icqcontact *) clist.get(*c);
 
-	    if(c->getuin())
-		m.additemf(0, (void *) c->getuin(), " [%c] %s",
-		    find(lst.begin(), lst.end(), c->getuin()) != lst.end()
-		    ? 'x' : ' ', c->getdispnick().c_str());
+	    m.additemf(0, (void *) *c, " [%c] %s",
+		find(lst.begin(), lst.end(), *c) != lst.end()
+		? 'x' : ' ', cont->getdispnick().c_str());
 	}
 
 	m.setpos(saveelem, savefirst);
@@ -1683,7 +1765,10 @@ bool icqface::multicontacts(string head, list<unsigned int> &lst) {
 		    if(c != lst.end()) lst.erase(c); else lst.push_back(ffuin);
 		}
 		break;
-	    case  0:
+	    case -3:
+		quickfind(&m);
+		break;
+	    case 0:
 		ret = false;
 	    default:
 		finished = true;
@@ -1708,6 +1793,10 @@ void icqface::log(const char *fmt, ...) {
 void icqface::log(string text) {
     int i;
 
+#ifdef DEBUG
+    if(flog.is_open()) flog << text << endl;
+#endif
+
     if(!mainscreenblock) {
 	chtype *logline = new chtype[WORKAREA_X2-WORKAREA_X1+2];
 	attrset(conf.getcolor(cp_main_text));
@@ -1747,7 +1836,7 @@ string icqface::quotemsg(string text) {
     vector<string> lines;
     vector<string>::iterator i;
 
-    formattext(text, lines, true, WORKAREA_X2-WORKAREA_X1-4);
+    breakintolines(text, lines, WORKAREA_X2-WORKAREA_X1-4);
 
     for(i = lines.begin(); i != lines.end(); i++) {
 	if(!i->empty()) ret += (string) "> " + *i;
@@ -1758,22 +1847,32 @@ string icqface::quotemsg(string text) {
     return ret;
 }
 
-void icqface::quickfind() {
+void icqface::quickfind(verticalmenu *multi = 0) {
     bool fin;
-    string nick, disp;
-    int k, i, len;
+    string nick, disp, upnick, upcurrent;
+    string::iterator is;
+    int k, i, len, lx, ly;
     bool found;
     icqcontact *c;
+    verticalmenu *cm = (multi ? multi : &mcontacts->menu);
 
     status(_("QuickSearch: type to find, Alt-S find again, Enter finish"));
 
+    if(multi) {
+	lx = WORKAREA_X1+2;
+	ly = WORKAREA_Y2;
+    } else {
+	lx = 2;
+	ly = LINES-2;
+    }
+
     for(fin = false; !fin; ) {
 	attrset(conf.getcolor(cp_main_frame));
-	mvhline(LINES-2, 2, HLINE, 23);
+	mvhline(ly, lx, HLINE, 23);
 	disp = nick;
 	if(disp.size() > 18) disp.replace(0, disp.size()-18, "");
-	kwriteatf(2, LINES-2, conf.getcolor(cp_main_highlight), "[ %s ]", disp.c_str());
-	kgotoxy(4+disp.size(), LINES-2);
+	kwriteatf(lx, ly, conf.getcolor(cp_main_highlight), "[ %s ]", disp.c_str());
+	kgotoxy(lx+2+disp.size(), ly);
 	refresh();
 
 	if(ihook.idle())
@@ -1788,18 +1887,21 @@ void icqface::quickfind() {
 		break;
 	    default:
 		if(isprint(k) || (k == ALT('s'))) {
-		    i = mcontacts->menu.getpos()+2;
+		    i = cm->getpos() + (multi ? 1 : 2);
 
 		    if(isprint(k)) {
-			nick += k;
 			i--;
+			nick += k;
 		    }
 
+		    for(is = nick.begin(), upnick = ""; is != nick.end(); is++)
+			upnick += toupper(*is);
+
 		    bool fin = false;
 		    bool fpass = true;
 
 		    for(; !fin; i++) {
-			if(i >= mcontacts->menu.getcount()) {
+			if(i >= cm->getcount()) {
 			    if(fpass) {
 				i = 0;
 				fpass = false;
@@ -1808,27 +1910,78 @@ void icqface::quickfind() {
 			    }
 			}
 
-			c = (icqcontact *) mcontacts->getref(i);
+			if(multi) c = clist.get((unsigned int) cm->getref(i));
+			else c = (icqcontact *) mcontacts->getref(i);
 
 			if((int) c > 10) {
-			    len = c->getdispnick().size();
+			    string current = c->getdispnick();
+			    len = current.size();
 			    if(len > nick.size()) len = nick.size();
+			    current.erase(len);
 
-			    if(!c->getdispnick().compare(nick, 0, len)) {
-				mcontacts->menu.setpos(i-1);
+			    for(is = current.begin(), upcurrent = "";
+			    is != current.end(); is++)
+				    upcurrent += toupper(*is);
+
+			    if(upnick == upcurrent) {
+				cm->setpos(i - (multi ? 0 : 1));
 				break;
 			    }
 			}
 		    }
 
-		    mcontacts->redraw();
+		    if(!multi) mcontacts->redraw();
+		    else cm->redraw();
 		}
 		break;
 	}
     }
 
     attrset(conf.getcolor(cp_main_frame));
-    mvhline(LINES-2, 2, HLINE, 23);
+    mvhline(ly, lx, HLINE, 23);
+}
+
+void icqface::extracturls(const string buf) {
+    int pos = 0;
+    regex_t r;
+    regmatch_t rm[1];
+    const char *pp = buf.c_str();
+
+    extractedurls.clear();
+    if(!regcomp(&r, "(http://[^ ,\t\n]+|ftp://[^, \t\n]+|www\\.[^, \t\n]+)", REG_EXTENDED)) {
+	while(!regexec(&r, buf.substr(pos).c_str(), 1, rm, 0)) {
+	    extractedurls.push_back(buf.substr(pos+rm[0].rm_so, rm[0].rm_eo-rm[0].rm_so));
+	    pos += rm[0].rm_eo;
+	}
+	regfree(&r);
+    }
+}
+
+void icqface::showextractedurls() {
+    if(extractedurls.empty()) {
+	log(_("+ no URLs within the current context"));
+    } else {
+	int n;
+	vector<string>::iterator i;
+	verticalmenu m(WORKAREA_X1+1, WORKAREA_Y1+3, WORKAREA_X2, WORKAREA_Y2,
+	    conf.getcolor(cp_main_text), conf.getcolor(cp_main_selected));
+
+	saveworkarea();
+	clearworkarea();
+	workarealine(WORKAREA_Y1+2);
+
+	mainw.writef(WORKAREA_X1+2, WORKAREA_Y1,
+	    conf.getcolor(cp_main_highlight),
+	    _("URLs within the current context"));
+
+	for(i = extractedurls.begin(); i != extractedurls.end(); i++)
+	    m.additem(" " + *i);
+
+	if(n = m.open())
+	    conf.openurl(extractedurls[n-1]);
+
+	restoreworkarea();
+    }
 }
 
 // ----------------------------------------------------------------------------
@@ -1888,12 +2041,12 @@ int icqface::contactskeys(verticalmenu *m, int k) {
 	case '/': face.extk = ACT_QUICKFIND; break;
     }
 
-    if(strchr("?rRqQsShHmMuUgGaAfFvV/", k)
+    if(k && (strchr("?rRqQsShHmMuUgGaAfFvV/", k)
 	|| (k == KEY_DC)
 	|| (k == KEY_F(2))
 	|| (k == KEY_F(3))
 	|| (k == KEY_F(4))
-	|| (k == ALT('s'))) {
+	|| (k == ALT('s')))) {
 	return m->getpos()+1;
     } else {
 	return -1;
@@ -1906,10 +2059,27 @@ int icqface::multiplekeys(verticalmenu *m, int k) {
 	case 'x':
 	case 'X':
 	    return -2;
+	case ALT('s'):
+	    return -3;
     }
     return -1;
 }
 
+int icqface::historykeys(dialogbox *db, int k) {
+    static string sub;
+
+    switch(k) {
+	case 's':
+	case 'S':
+	    return -2;
+	case 'l':
+	case 'L':
+	    return -3;
+    }
+
+    return -1;
+}
+
 int icqface::editmsgkeys(texteditor *e, int k) {
     char *p;
 
@@ -1927,6 +2097,14 @@ int icqface::editmsgkeys(texteditor *e, int k) {
     return 0;
 }
 
+int icqface::userinfokeys(dialogbox *db, int k) {
+    switch(k) {
+	case KEY_F(2): face.showextractedurls(); break;
+    }
+
+    return -1;
+}
+
 void icqface::editidle(texteditor *e) {
     ihook.idle();
 }
@@ -1966,7 +2144,7 @@ void icqprogress::show(string title = "") {
 	conf.getcolor(cp_dialog_frame), TW_CENTERED);
     }
 
-    w->set_title(conf.getcolor(cp_dialog_highlight), title.c_str());
+    w->set_title(conf.getcolor(cp_dialog_highlight), title);
     w->open();
 }
 
