@@ -1,8 +1,9 @@
 #ifndef __ICQFACE_H__
 #define __ICQFACE_H__
 
-#include "icq.h"
+#include <fstream>
 
+#include "icq.h"
 #include "icqhist.h"
 
 #include "konst.ui.dlg.h"
@@ -78,6 +79,8 @@ class icqface {
 	textinputline *il;
 	textwindow mainw;
 	filemanager *fm;
+	ofstream flog;
+	vector<string> extractedurls;
 
 	linkedlist workareas;
 
@@ -93,6 +96,8 @@ class icqface {
 	static int editaboutkeys(texteditor *e, int k);
 	static int contactskeys(verticalmenu *m, int k);
 	static int multiplekeys(verticalmenu *m, int k);
+	static int historykeys(dialogbox *m, int k);
+	static int userinfokeys(dialogbox *db, int k);
 
 	static void editidle(texteditor *e);
 	static void textbrowseridle(textbrowser *b);
@@ -123,6 +128,8 @@ class icqface {
 	void workarealine(int l);
 
 	string quotemsg(string text);
+	void showextractedurls();
+	void extracturls(const string buf);
 
     public:
 	list<unsigned int> muins;
@@ -186,7 +193,7 @@ class icqface {
 	string inputstr(string q, string defl = "", char passwdchar = 0);
 	string inputfile(string q, string defl = "");
 
-	void quickfind();
+	void quickfind(verticalmenu *multi = 0);
 };
 
 extern icqface face;
