@@ -8,6 +8,9 @@
 #include "icqmlist.h"
 #include "centericq.h"
 
+#include <netinet/in.h>
+#include <arpa/inet.h>
+
 #define TIMESTAMP ihook.maketm(hour, minute, day, month, year)
 
 icqhook::icqhook(): flogged(false), newuin(0), finddest(0),
@@ -207,7 +210,7 @@ const char *msg) {
 void icqhook::chat(struct icq_link *link, unsigned long uin,
 unsigned char hour, unsigned char minute, unsigned char day,
 unsigned char month, unsigned short year, const char *descr,
-unsigned long seq, const char *session, unsigned long port) {
+unsigned long seq /*, const char *session, unsigned long port*/) {
     if(!lst.inlist(uin, csignore)) {
 	icqcontact *c = clist.get(uin);
 	if(c) {
@@ -237,6 +240,7 @@ unsigned char month, unsigned short year, const char *nick,
 const char *first, const char *last, const char *email) {
     if(!lst.inlist(uin, csignore)) {
 	string text = (string) "I" + i2str(uin) + " " + first + " " + last + " ";
+	if(nick[0]) text += (string) "aka " + nick + " ";
 	if(email[0]) text += (string) "<" + email + "> ";
 	text += (string) _("has added you to his/her contact list");
 	hist.putmessage(0, text, HIST_MSG_IN, TIMESTAMP);
@@ -252,6 +256,7 @@ const char *first, const char *last, const char *email,
 const char *reason) {
     if(!lst.inlist(uin, csignore)) {
 	string text = (string) "R" + i2str(uin) + " " + first + " " + last + " ";
+	if(nick[0]) text += (string) "aka " + nick + " ";
 	if(email[0]) text += (string) "<" + email + "> ";
 	text += (string) _("has requested your authorization to add you to his/her contact list. The reason was: ") + reason;
 	hist.putmessage(0, text, HIST_MSG_IN, TIMESTAMP);
@@ -264,14 +269,24 @@ void icqhook::useronline(struct icq_link *link, unsigned long uin,
 unsigned long status, unsigned long ip, unsigned short port,
 unsigned long real_ip, unsigned char tcp_flag) {
     icqcontact *c = clist.get(uin);
-    unsigned char *bip = (unsigned char *)(&ip);
     time_t curtime = time(0);
 
-    string lastip =
-	i2str(bip[3]) + "." +
-	i2str(bip[2]) + "." +
-	i2str(bip[1]) + "." +
-	i2str(bip[0]);
+    string lastip, sip, srip, sip_rev;
+    unsigned char *bip = (unsigned char *) &ip;
+    unsigned char *brip = (unsigned char *) &real_ip;
+    string::reverse_iterator ch;
+
+    sip = i2str(bip[3]) + "." + i2str(bip[2]) + "." + i2str(bip[1]) + "." + i2str(bip[0]);
+    srip = i2str(brip[3]) + "." + i2str(brip[2]) + "." + i2str(brip[1]) + "." + i2str(brip[0]);
+
+    for(ch = sip.rbegin(); ch != sip.rend(); ch++)
+	sip_rev += *ch;
+
+    if(sip != "0.0.0.0") lastip = sip;
+    if(srip != "0.0.0.0" && srip != sip && srip != sip_rev) {
+	if(!lastip.empty()) lastip += " ";
+	lastip += srip;
+    }
 
     if(c) {
 	c->setstatus(status);
@@ -528,7 +543,7 @@ void icqhook::exectimers() {
 	if((!seq_keepalive &&
 	(period > (conf.getsockshost().empty() ? PERIOD_KEEPALIVE : PERIOD_SOCKSALIVE))) ||
 	(seq_keepalive && (period > PERIOD_WAIT_KEEPALIVE))) {
-	    if(!seq_keepalive) offl.scan(0, osexpired);
+//            if(!seq_keepalive) offl.scan(0, osexpired);
 	    seq_keepalive = icq_KeepAlive(&icql);
 	    n_keepalive++;
 	    time(&timer_keepalive);
@@ -549,6 +564,8 @@ void icqhook::exectimers() {
 		    c->incinfotryn();
 		}
 	    }
+
+	    offl.scan(0, osexpired);
 	    time(&timer_resolve);
 	}
 	else
